"use strict";
exports.isSameQuarter = void 0;

var _index = require("../isSameQuarter.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const isSameQuarter = (exports.isSameQuarter = (0, _index2.convertToFP)(
  _index.isSameQuarter,
  2,
));
