export declare const clamp: import("./types.js").FPFn2<
  Date,
  import("../fp.js").Interval<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>
  >,
  import("../fp.js").DateArg<Date>
>;
