"use strict";
exports.subSeconds = void 0;

var _index = require("../subSeconds.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const subSeconds = (exports.subSeconds = (0, _index2.convertToFP)(
  _index.subSeconds,
  2,
));
