export declare const closestToWithOptions: import("./types.js").FPFn3<
  Date | undefined,
  import("../closestTo.js").ClosestToOptions<Date> | undefined,
  import("../fp.js").DateArg<Date>[],
  import("../fp.js").DateArg<Date>
>;
