export declare const isSameISOWeekWithOptions: import("./types.js").FPFn3<
  boolean,
  import("../isSameISOWeek.js").IsSameISOWeekOptions | undefined,
  string | number | Date,
  string | number | Date
>;
