export declare const differenceInCalendarISOWeekYearsWithOptions: import("./types.js").FPFn3<
  number,
  | import("../differenceInCalendarISOWeekYears.js").DifferenceInCalendarISOWeekYearsOptions
  | undefined,
  string | number | Date,
  string | number | Date
>;
