"use strict";
exports.startOfMonthWithOptions = void 0;

var _index = require("../startOfMonth.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const startOfMonthWithOptions = (exports.startOfMonthWithOptions = (0,
_index2.convertToFP)(_index.startOfMonth, 2));
