"use strict";
exports.getDate = void 0;

var _index = require("../getDate.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const getDate = (exports.getDate = (0, _index2.convertToFP)(_index.getDate, 1));
