export declare const previousSaturdayWithOptions: import("./types.js").FPFn2<
  Date,
  | import("../previousSaturday.js").PreviousSaturdayOptions<Date>
  | undefined,
  import("../fp.js").DateArg<Date>
>;
