"use strict";
exports.getISOWeeksInYear = void 0;

var _index = require("../getISOWeeksInYear.cjs");
var _index2 = require("./_lib/convertToFP.cjs"); // This file is generated automatically by `scripts/build/fp.ts`. Please, don't change it.

const getISOWeeksInYear = (exports.getISOWeeksInYear = (0, _index2.convertToFP)(
  _index.getISOWeeksInYear,
  1,
));
