export declare const isWithinIntervalWithOptions: import("./types.js").FPFn3<
  boolean,
  import("../isWithinInterval.js").IsWithinIntervalOptions | undefined,
  import("../fp.js").Interval<
    import("../fp.js").DateArg<Date>,
    import("../fp.js").DateArg<Date>
  >,
  string | number | Date
>;
