export declare const setDayOfYearWithOptions: import("./types.js").FPFn3<
  Date,
  import("../setDayOfYear.js").SetDayOfYearOptions<Date> | undefined,
  number,
  import("../fp.js").DateArg<Date>
>;
