export declare const nextDayWithOptions: import("./types.js").FPFn3<
  Date,
  import("../nextDay.js").NextDayOptions<Date> | undefined,
  import("../fp.js").Day,
  import("../fp.js").DateArg<Date>
>;
