export declare const constructFrom: import("./types.js").FPFn2<
  Date,
  string | number | Date,
  | import("../fp.js").ContextFn<Date>
  | import("../fp.js").DateArg<
      Date | import("../fp.js").ConstructableDate
    >
  | undefined
>;
